@@ -23,7 +23,7 @@
 #include "IDB.h"
 #include "CDiary.h"
 
-#include <QPointer>
+#include <QMap>
 
 class CDiaryEditWidget;
 
@@ -35,22 +35,33 @@ class CDiaryDB : public IDB
 
         static CDiaryDB& self(){return *m_self;}
 
-        void openEditWidget();
-        const QString getDiary();
+        void addDiary(CDiary * diary, bool silent, bool fromDB);
+        void delDiary(const QString& key, bool silent);
+        void delDiarys(const QStringList& keys);
+
+        CDiary * getDiaryByKey(const QString& key);
 
         void loadGPX(CGpx& gpx);
         void saveGPX(CGpx& gpx, const QStringList& keys);
 
-        void loadQLB(CQlb& qlb);
+        void loadQLB(CQlb& qlb, bool newKey);
         void saveQLB(CQlb& qlb);
 
-        void upload(const QStringList& ){};
-        void download(){};
+        void upload(const QStringList& ){}
+        void download(){}
 
         void clear();
 
         int count();
 
+        bool contains(const QString& key){return diarys.contains(key);}
+
+        QMap<QString,CDiary*> ::iterator begin(){return diarys.begin();}
+        QMap<QString,CDiary*> ::iterator end(){return diarys.end();}
+
+        void setModified(const QStringList& keys);
+
+
     private:
         friend class CMainWindow;
         friend class CDiaryEditWidget;
@@ -59,8 +70,6 @@ class CDiaryDB : public IDB
 
         static CDiaryDB * m_self;
 
-        QPointer<CDiaryEditWidget> editWidget;
-
-        CDiary diary;
+        QMap<QString,CDiary*> diarys;
 };
 #endif                           //CDIARYDB_H
