@@ -1,26 +1,23 @@
 /**********************************************************************************************
+    Copyright (C) 2012 Oliver Eichler oliver.eichler@gmx.de
 
-  DSP Solutions GmbH & Co. KG
-  http://www.dspsolutions.de/
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
 
-  Author:      Oliver Eichler
-  Email:       oliver.eichler@dspsolutions.de
-  Phone:       +49-941-83055-1
-  Fax:         +49-941-83055-79
-
-  File:        CDiaryEdit.cpp
-
-  Module:
-
-  Description:
-
-  Created:     06/10/2011
-
-  (C) 2011 DSP Solutions. All rights reserved.
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
 
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 **********************************************************************************************/
 
+
 #include "CDiaryEdit.h"
 #include "CGeoDB.h"
 #include "CDiary.h"
@@ -36,6 +33,7 @@
 #include "CCanvas.h"
 #include "CPlot.h"
 #include "IUnit.h"
+#include "CSettings.h"
 
 #include <QtGui>
 
@@ -163,7 +161,7 @@ CDiaryEdit::CDiaryEdit(CDiary& diary, QWidget * parent)
     textEdit->setFocus();
     colorChanged(textEdit->textColor());
 
-    QSettings cfg;
+    SETTINGS;
     checkGeoCache->setChecked(cfg.value("diary/showGeoCaches", false).toBool());
     connect(checkGeoCache, SIGNAL(clicked()), this, SLOT(slotIntReload()));
 
@@ -178,7 +176,7 @@ CDiaryEdit::~CDiaryEdit()
 {
     collectData();
 
-    QSettings cfg;
+    SETTINGS;
     cfg.setValue("diary/showGeoCaches", checkGeoCache->isChecked());
     cfg.setValue("diary/showProfiles", checkProfile->isChecked());
     cfg.setValue("diary/addMapView", checkAddMap->isChecked());
@@ -275,6 +273,9 @@ void CDiaryEdit::slotReload()
 void CDiaryEdit::slotReload(bool fromDB)
 {
     CDiaryEditLock lock(this);
+
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+
     if(fromDB)
     {
         if(CGeoDB::self().getProjectDiaryData(diary.keyProjectGeoDB, diary))
@@ -288,6 +289,8 @@ void CDiaryEdit::slotReload(bool fromDB)
     textEdit->clear();
     textEdit->document()->setTextWidth(textEdit->size().width() - 20);
     draw(*textEdit->document());
+
+    QApplication::restoreOverrideCursor();
 }
 
 void CDiaryEdit::slotPrintPreview()
@@ -445,6 +448,7 @@ void CDiaryEdit::colorChanged(const QColor &c)
 
 void CDiaryEdit::slotCursorPositionChanged()
 {
+    int i;
     if(isInternalEdit) return;
 
     QTextCursor cursor = textEdit->textCursor();
@@ -457,7 +461,7 @@ void CDiaryEdit::slotCursorPositionChanged()
         }
     }
 
-    for(int i = 1; i <= diary.wpts.count(); i++)
+    for(i = 1; i <= diary.wpts.count(); i++)
     {
         QTextTable * tbl = diary.tblWpt;
         if(tbl->cellAt(i, eComment).firstCursorPosition() <= cursor && cursor <= tbl->cellAt(i, eComment).lastCursorPosition())
@@ -472,23 +476,30 @@ void CDiaryEdit::slotCursorPositionChanged()
         }
     }
 
-    for(int i = 1; i <= diary.trks.count(); i++)
+    QTextTable * tbl = diary.tblTrk;
+    if(tbl)
     {
-
-        QTextTable * tbl = diary.tblTrk;
-        if(tbl->cellAt(i, eComment).firstCursorPosition() <= cursor && cursor <= tbl->cellAt(i, eComment).lastCursorPosition())
+        for(i = 1; i <= diary.trks.count(); i++)
         {
-            return;
+            if(tbl->cellAt(i, eComment).firstCursorPosition() <= cursor && cursor <= tbl->cellAt(i, eComment).lastCursorPosition())
+            {
+                return;
+            }
+
+            if(tbl->cellAt(i, eSym).firstCursorPosition() <= cursor && cursor <= tbl->cellAt(i, eInfo).lastCursorPosition())
+            {
+                textEdit->setTextCursor(tbl->cellAt(i, eComment).lastCursorPosition());
+                return;
+            }
         }
 
-        if(tbl->cellAt(i, eSym).firstCursorPosition() <= cursor && cursor <= tbl->cellAt(i, eInfo).lastCursorPosition())
+        if(cursor > tbl->cellAt(i-1, eComment).lastCursorPosition())
         {
-            textEdit->setTextCursor(tbl->cellAt(i, eComment).lastCursorPosition());
+            textEdit->setTextCursor(tbl->cellAt(i-1, eComment).lastCursorPosition());
             return;
         }
     }
 
-
     if(!diary.diaryFrame.isNull())
     {
         textEdit->setTextCursor(diary.diaryFrame->lastCursorPosition());
@@ -576,8 +587,9 @@ void CDiaryEdit::draw(QTextDocument& doc)
 
     QTextCharFormat fmtCharHeader;
     fmtCharHeader.setFont(f);
-    fmtCharHeader.setBackground(QColor("#c6e3c0"));
+    fmtCharHeader.setBackground(Qt::darkBlue);
     fmtCharHeader.setFontWeight(QFont::Bold);
+    fmtCharHeader.setForeground(Qt::white);
 
     QTextBlockFormat fmtBlockStandard;
     fmtBlockStandard.setTopMargin(10);
@@ -833,9 +845,9 @@ void CDiaryEdit::collectData()
 
         foreach(CWpt* wpt, wpts)
         {
-            if(cnt < diary.tblWpt->columns())
+            if(cnt < diary.tblWpt->rows())
             {
-                wpt->setComment(QLGT::QTextHtmlExporter(textEdit->document()).toHtml(diary.tblWpt->cellAt(cnt, 2)));
+                wpt->setComment(QLGT::QTextHtmlExporter(textEdit->document()).toHtml(diary.tblWpt->cellAt(cnt, eComment)));
             }
             cnt++;
         }
@@ -849,9 +861,9 @@ void CDiaryEdit::collectData()
 
         foreach(CTrack* trk, trks)
         {
-            if(cnt < diary.tblTrk->columns())
+            if(cnt < diary.tblTrk->rows())
             {
-                trk->setComment(QLGT::QTextHtmlExporter(textEdit->document()).toHtml(diary.tblTrk->cellAt(cnt, 2)));
+                trk->setComment(QLGT::QTextHtmlExporter(textEdit->document()).toHtml(diary.tblTrk->cellAt(cnt, eComment)));
             }
             cnt++;
         }
