@@ -27,6 +27,7 @@
 #include "CDlgSetupGarminIcons.h"
 
 #include <QtGui>
+#include <QNetworkProxy>
 
 #define XSTR(x) STR(x)
 #define STR(x) #x
@@ -44,12 +45,11 @@ CDlgConfig::CDlgConfig(QWidget * parent)
     connect(toolWptTextColor,SIGNAL(clicked()),this,SLOT(slotSelectWptTextColor()));
     fillTypeCombo();
 
-#ifndef HAS_GEODB
-    groupBoxGeoDB->hide();
     connect(toolPathGeoDB, SIGNAL(clicked()),this,SLOT(slotSelectPathGeoDB()));
     connect(checkUseGeoDB, SIGNAL(clicked(bool)), groupSaveWks, SLOT(setEnabled(bool)));
     connect(checkGeoDBSaveOnExit, SIGNAL(clicked(bool)), spinGeoDBMinutes, SLOT(setEnabled(bool)));
-#endif
+
+    connect(toolPathMapCache, SIGNAL(clicked()), this, SLOT(slotSelectPathMapCache()));
 
 }
 
@@ -91,18 +91,20 @@ void CDlgConfig::exec()
     checkShowZoomLevel->setChecked(resources.m_showZoomLevel);
     checkAntiAliasing->setChecked(resources.m_useAntiAliasing);
     checkReducePoiIcons->setChecked(resources.m_reducePoiIcons);
-#ifdef HAS_GEODB
+
     checkUseGeoDB->setChecked(resources.m_useGeoDB);
     groupSaveWks->setEnabled(resources.m_useGeoDB);
     checkGeoDBSaveOnExit->setChecked(resources.m_saveGeoDBOnExit);
     spinGeoDBMinutes->setValue(resources.m_saveGeoDBMinutes);
     labelPathGeoDB->setText(resources.m_pathGeoDB.absolutePath());
-#endif
+
 
 
     comboDevice->addItem(tr(""),"");
     comboDevice->addItem(tr("QLandkarte M"), "QLandkarteM");
     comboDevice->addItem(tr("Garmin"), "Garmin");
+    comboDevice->addItem(tr("Garmin Mass Storage"), "Garmin Mass Storage");
+    comboDevice->addItem(tr("TwoNav"), "TwoNav");
     comboDevice->addItem(tr("NMEA"), "NMEA");
 
     comboDevBaudRate->addItem("4800");
@@ -142,6 +144,9 @@ void CDlgConfig::exec()
     palette.setColor(labelWptTextColor->foregroundRole(), resources.m_WptTextColor);
     labelWptTextColor->setPalette(palette);
 
+    labelPathMapCache->setText(resources.m_pathMapCache.absolutePath());
+    spinSizeMapCache->setValue(resources.m_sizeMapCache);
+    spinExpireMapCache->setValue(resources.m_expireMapCache);
 
     QDialog::exec();
 }
@@ -155,7 +160,10 @@ void CDlgConfig::accept()
     resources.m_httpProxy       = lineProxyURL->text();
     resources.m_httpProxyPort   = lineProxyPort->text().toUInt();
 
-    emit resources.sigProxyChanged();
+    if(resources.m_useHttpProxy)
+      QNetworkProxy::setApplicationProxy(QNetworkProxy(QNetworkProxy::HttpProxy,resources.m_httpProxy,resources.m_httpProxyPort));
+    else
+      QNetworkProxy::setApplicationProxy(QNetworkProxy(QNetworkProxy::NoProxy));
 
     resources.m_mapfont         = labelFont->font();
 
@@ -182,13 +190,10 @@ void CDlgConfig::accept()
     resources.m_useAntiAliasing = checkAntiAliasing->isChecked();
     resources.m_reducePoiIcons  = checkReducePoiIcons->isChecked();
 
-#ifdef HAS_GEODB
     resources.m_useGeoDB        = checkUseGeoDB->isChecked();
     resources.m_saveGeoDBOnExit = checkGeoDBSaveOnExit->isChecked();
     resources.m_saveGeoDBMinutes = spinGeoDBMinutes->value();
     resources.m_pathGeoDB       = QDir(labelPathGeoDB->text());
-#endif
-
 
     resources.m_devKey          = comboDevice->itemData(comboDevice->currentIndex()).toString();
     resources.m_devIPAddress    = lineDevIPAddr->text();
@@ -213,8 +218,12 @@ void CDlgConfig::accept()
     IDevice::m_UploadAllTrk     = checkUploadTrk->isChecked();
     IDevice::m_UploadAllRte     = checkUploadRte->isChecked();
 
-    QPalette palette = labelWptTextColor->palette();
-    resources.m_WptTextColor = palette.color(labelWptTextColor->foregroundRole());
+    QPalette palette            = labelWptTextColor->palette();
+    resources.m_WptTextColor    = palette.color(labelWptTextColor->foregroundRole());
+
+    resources.m_pathMapCache    = QDir(labelPathMapCache->text());
+    resources.m_sizeMapCache    = spinSizeMapCache->value();
+    resources.m_expireMapCache  = spinExpireMapCache->value();
 
     QDialog::accept();
 }
@@ -373,3 +382,13 @@ void CDlgConfig::slotSelectWptTextColor()
     }
 
 }
+
+void CDlgConfig::slotSelectPathMapCache()
+{
+    QString path = QFileDialog::getExistingDirectory(this, tr("Open Directory"), labelPathMapCache->text(), QFileDialog::ShowDirsOnly);
+    if(!path.isEmpty())
+    {
+        labelPathMapCache->setText(path);
+    }
+}
+
