@@ -27,6 +27,7 @@
 #include "CMapDB.h"
 #include "IMap.h"
 #include "IUnit.h"
+#include "CSettings.h"
 
 #include "config.h"
 
@@ -51,6 +52,8 @@ CDlgEditWpt::CDlgEditWpt(CWpt &wpt, QWidget * parent)
     connect(labelLink, SIGNAL(linkActivated(const QString&)),this,SLOT(slotOpenLink(const QString&)));
     connect(toolLink, SIGNAL(pressed()),this,SLOT(slotEditLink()));
     connect(checkHint, SIGNAL(toggled(bool)), this, SLOT(slotToggleHint(bool)));
+    connect(pushCreateBuddies, SIGNAL(clicked()), this, SLOT(slotCreateBuddies()));
+    connect(checkTransparent, SIGNAL(toggled(bool)), this, SLOT(slotTransparent(bool)));
 
     labelUnitElevation->setText(IUnit::self().baseunit);
     labelUnitProximity->setText(IUnit::self().baseunit);
@@ -67,7 +70,26 @@ CDlgEditWpt::CDlgEditWpt(CWpt &wpt, QWidget * parent)
 #ifdef HAS_DMTX
     enc = dmtxEncodeCreate();
 #endif
+    SETTINGS;
+    checkTransparent->setChecked(cfg.value("waypoint/transparent", false).toBool());
 
+    imageSelect->setTransparent(true);
+    name = wpt.getName();
+    imageSelect->setWpt(&wpt);
+    connect(imageSelect, SIGNAL(sigSelectImage(const CImageSelect::img_t&)), this, SLOT(slotSelectImage(const CImageSelect::img_t&)));
+
+    if(wpt.isGeoCache())
+    {
+        labelSpolerHint->show();
+        imageSelect->hide();
+        checkTransparent->hide();
+    }
+    else
+    {
+        labelSpolerHint->hide();
+        imageSelect->show();
+        checkTransparent->show();
+    }
 }
 
 
@@ -77,6 +99,10 @@ CDlgEditWpt::~CDlgEditWpt()
 #ifdef HAS_DMTX
     dmtxEncodeDestroy(&enc);
 #endif
+
+    SETTINGS;
+    cfg.setValue("waypoint/transparent", checkTransparent->isChecked());
+
 }
 
 
@@ -151,14 +177,15 @@ int CDlgEditWpt::exec()
 
     if(wpt.isGeoCache())
     {
-        checkExportBuddies->setChecked(wpt.geocache.exportBuddies);
+//        checkExportBuddies->setChecked(wpt.geocache.exportBuddies);
 
         wpt.showBuddies(true);
 
         if(wpt.buddies.isEmpty())
         {
             listBuddies->hide();
-            checkExportBuddies->hide();
+//            checkExportBuddies->hide();
+            pushCreateBuddies->hide();
         }
         else
         {
@@ -171,8 +198,6 @@ int CDlgEditWpt::exec()
                 listBuddies->addItem(item);
 
 
-                qDebug() << buddy.pos << buddy.name;
-
                 foreach(const QString& pos, buddy.pos)
                 {
                     html.replace(pos, QString("%1 (<b><i style='color: black;'>%2</i></b>)").arg(pos).arg(buddy.name));
@@ -180,20 +205,29 @@ int CDlgEditWpt::exec()
             }
             listBuddies->sortItems();
             listBuddies->show();
-            checkExportBuddies->show();
+//            checkExportBuddies->show();
+            pushCreateBuddies->show();
         }
+
+        webView->setHtml(html);
+        webView->page()->setLinkDelegationPolicy( QWebPage::DelegateAllLinks );
+        checkHint->setEnabled(wpt.hasHiddenInformation());
+
     }
     else
     {
         listBuddies->hide();
-        checkExportBuddies->hide();
+//        checkExportBuddies->hide();
+        pushCreateBuddies->hide();
+        checkHint->hide();
+
+        if(!link.isEmpty())
+        {
+            webView->setUrl(link);
+        }
     }
 
 
-    webView->setHtml(html);
-    webView->page()->setLinkDelegationPolicy( QWebPage::DelegateAllLinks );
-
-    checkHint->setEnabled(wpt.hasHiddenInformation());
 
 
     QStringList caches;
@@ -220,6 +254,8 @@ int CDlgEditWpt::exec()
 
     }
 
+    lineName->setFocus();
+
     return QDialog::exec();
 }
 
@@ -264,7 +300,7 @@ void CDlgEditWpt::accept()
         double bearing  = lineBearing->text().toDouble() * DEG_TO_RAD;
         double distance = lineDistance->text().toDouble();
 
-        XY pt1, pt2;
+        projXY pt1, pt2;
         pt1.u       = wpt.lon * DEG_TO_RAD;
         pt1.v       = wpt.lat * DEG_TO_RAD;
         pt2         = GPS_Math_Wpt_Projection(pt1, distance, bearing);
@@ -282,7 +318,7 @@ void CDlgEditWpt::accept()
         CWptDB::self().addWpt(wpt2,false);
     }
 
-    wpt.geocache.exportBuddies = checkExportBuddies->isChecked();
+//    wpt.geocache.exportBuddies = checkExportBuddies->isChecked();
 
     wpt.parentWpt = comboParentWpt->currentText();
 
@@ -290,6 +326,11 @@ void CDlgEditWpt::accept()
     emit CWptDB::self().sigModified();
     emit CWptDB::self().sigModified(wpt.getKey());
 
+    if(wpt.getName() != name)
+    {
+        CWptDB::self().setNewWptName(wpt.getName());
+    }
+
     QDialog::accept();
 }
 
@@ -355,7 +396,18 @@ void CDlgEditWpt::showImage(int idx)
         idxImg = idx;
 
         CWpt::image_t& img = wpt.images[idx];
-        labelImage->setPixmap(img.pixmap.scaledToWidth(100,Qt::SmoothTransformation));
+        if(wpt.isGeoCache())
+        {
+            QPixmap tmp = img.pixmap.scaledToWidth(300,Qt::SmoothTransformation);
+            labelImage->setMinimumSize(tmp.size());
+            labelImage->setPixmap(tmp);
+        }
+        else
+        {
+            QPixmap tmp = img.pixmap.scaledToWidth(150,Qt::SmoothTransformation);
+            labelImage->setMinimumSize(tmp.size());
+            labelImage->setPixmap(tmp);
+        }
         labelInfo->setText(img.info);
 
         pushNext->setEnabled(idx < (wpt.images.count() - 1) && wpt.images.count() != 1);
@@ -486,3 +538,42 @@ void CDlgEditWpt::slotToggleHint(bool show)
     }
     webView->setHtml(html);
 }
+
+void CDlgEditWpt::slotSelectImage(const CImageSelect::img_t& src)
+{
+    wpt.images.clear();
+
+    CWpt::image_t tar;
+    tar.filename    = src.filename;
+    tar.info        = src.title;
+    tar.pixmap      = src.img;
+
+    wpt.images << tar;
+
+    showImage(0);
+
+    textComment->setText(src.title);
+
+    pushDel->setEnabled(wpt.images.count() != 0);
+}
+
+void CDlgEditWpt::slotCreateBuddies()
+{
+    IMap& dem = CMapDB::self().getDEM();
+
+    wpt.showBuddies(true);
+    const QList<CWpt::buddy_t>& buddies = wpt.buddies;
+    foreach(const CWpt::buddy_t& buddy, buddies)
+    {
+        CWpt * w = CWptDB::self().newWpt(buddy.lon, buddy.lat, dem.getElevation(buddy.lon, buddy.lat), buddy.name);
+        w->setIcon("Civil");
+        w->setParentWpt(wpt.getName());
+    }
+
+    wpt.showBuddies(false);
+}
+
+void CDlgEditWpt::slotTransparent(bool ok)
+{
+    imageSelect->setTransparent(ok);
+}
