@@ -22,6 +22,8 @@
 #include <QDialog>
 
 #include "ui_IDlgEditWpt.h"
+#include "CImageSelect.h"
+
 #ifdef HAS_DMTX
 #include <dmtx.h>
 #endif //HAS_DMTX
@@ -53,9 +55,13 @@ class CDlgEditWpt : public QDialog, private Ui::IDlgEditWpt
         void slotSaveBarcode();
         void slotUpdateBarcode();
         void slotToggleHint(bool show);
+        void slotSelectImage(const CImageSelect::img_t& img);
+        void slotCreateBuddies();
+        void slotTransparent(bool ok);
 
     private:
         void showImage(int idx);
+
         CWpt &wpt;
         qint32 idxImg;
         QString link;
@@ -65,5 +71,6 @@ class CDlgEditWpt : public QDialog, private Ui::IDlgEditWpt
 #ifdef HAS_DMTX
         DmtxEncode * enc;
 #endif
+        QString name;
 };
 #endif                           //CDLGEDITWPT_H
