@@ -19,6 +19,7 @@
 
 #include "CDlgProjWizzard.h"
 #include "mitab.h"
+#include <proj_api.h>
 
 #include <QtGui>
 
@@ -67,6 +68,43 @@ CDlgProjWizzard::CDlgProjWizzard(QLineEdit& line, QWidget * parent)
     connect(comboHemisphere, SIGNAL(currentIndexChanged(int)), this, SLOT(slotChange()));
     connect(lineUserDef, SIGNAL(textChanged(const QString&)), this, SLOT(slotChange()));
     connect(spinUTMZone, SIGNAL(valueChanged(int)), this, SLOT(slotChange()));
+
+    QString projstr = line.text();
+    QRegExp re1("\\+proj=longlat\\s(.*)");
+    QRegExp re2("\\+proj=merc \\+a=6378137 \\+b=6378137 \\+lat_ts=0.0 \\+lon_0=0.0 \\+x_0=0.0 \\+y_0=0 \\+k=1.0 \\+units=m \\+nadgrids=@null \\+no_defs");
+    QRegExp re3("\\+proj=merc\\s(.*)");
+    QRegExp re4("\\+proj=utm \\+zone=([0-9]+)\\s(.*)");
+
+    if(re1.exactMatch(projstr))
+    {
+        radioLonLat->setChecked(true);
+        findDatum(re1.cap(1));
+    }
+    else if(re2.exactMatch(projstr))
+    {
+        radioWorldMercator->setChecked(true);
+    }
+    else if(re3.exactMatch(projstr))
+    {
+        radioMercator->setChecked(true);
+        findDatum(re3.cap(1));
+    }
+    else if(re4.exactMatch(projstr))
+    {
+        radioUTM->setChecked(true);
+        spinUTMZone->setValue(re4.cap(1).toInt());
+
+        QString datum = re4.cap(2);
+        if(datum.startsWith("+south "))
+        {
+            datum = datum.mid(7);
+            comboHemisphere->setCurrentIndex(1);
+        }
+
+        findDatum(datum);
+    }
+
+    slotChange();
 }
 
 
@@ -75,6 +113,40 @@ CDlgProjWizzard::~CDlgProjWizzard()
 
 }
 
+void CDlgProjWizzard::findDatum(const QString& str)
+{
+    QString cmp;
+    int idx = 0;
+    const MapInfoDatumInfo * di   = asDatumInfoListQL;
+
+    while(di->nMapInfoDatumID != -1)
+    {
+
+        cmp.clear();
+        if(di->pszOGCDatumName != QString(""))
+        {
+            const MapInfoSpheroidInfo * si = asSpheroidInfoList;
+            while(si->nMapInfoId != -1)
+            {
+                if(si->nMapInfoId == di->nEllipsoid) break;
+                ++si;
+            }
+
+            cmp += QString("+a=%1 +b=%2 ").arg(si->dfA,0,'f',4).arg(si->dfA * (1.0 - (1.0/si->dfInvFlattening)),0,'f',4);
+            cmp += QString("+towgs84=%1,%2,%3,%4,%5,%6,%7,%8 ").arg(di->dfShiftX).arg(di->dfShiftY).arg(di->dfShiftZ).arg(di->dfDatumParm0).arg(di->dfDatumParm1).arg(di->dfDatumParm2).arg(di->dfDatumParm3).arg(di->dfDatumParm4);
+            cmp += "+units=m  +no_defs";
+        }
+
+        if(cmp == str)
+        {
+            comboDatum->setCurrentIndex(comboDatum->findText(di->pszOGCDatumName));
+            break;
+        }
+
+        ++di;++idx;
+    }
+
+}
 
 void CDlgProjWizzard::slotChange()
 {
@@ -95,7 +167,7 @@ void CDlgProjWizzard::slotChange()
     }
     else if(radioUTM->isChecked())
     {
-        str += QString("+proj=utm +zone=%1 %2").arg(spinUTMZone->value()).arg(comboHemisphere->itemData(comboHemisphere->currentIndex()).toString());
+        str += QString("+proj=utm +zone=%1 %2 ").arg(spinUTMZone->value()).arg(comboHemisphere->itemData(comboHemisphere->currentIndex()).toString());
 
     }
     else if(radioUserDef->isChecked())
@@ -104,7 +176,7 @@ void CDlgProjWizzard::slotChange()
     }
 
     int idx = comboDatum->itemData(comboDatum->currentIndex()).toInt();
-    const MapInfoDatumInfo      di = asDatumInfoListQL[idx];
+    const MapInfoDatumInfo di = asDatumInfoListQL[idx];
     if(di.pszOGCDatumName != QString(""))
     {
         const MapInfoSpheroidInfo * si = asSpheroidInfoList;
@@ -125,6 +197,26 @@ void CDlgProjWizzard::slotChange()
 
 void CDlgProjWizzard::accept()
 {
-    line.setText(labelResult->text());
-    QDialog::accept();
+    if (CDlgProjWizzard::validProjStr(labelResult->text()))
+    {
+        line.setText(labelResult->text());
+        line.setCursorPosition(0);
+        QDialog::accept();
+    }
+}
+
+bool CDlgProjWizzard::validProjStr(const QString projStr)
+{
+    projPJ projCheck = pj_init_plus(projStr.toUtf8().data());
+
+    if (!projCheck)
+    {
+        QMessageBox::warning(0, tr("Error..."),tr("The value\n'%1'\nis not a valid coordinate system definition:\n%2").arg(projStr).arg(pj_strerrno(pj_errno)),QMessageBox::Abort,QMessageBox::Abort);
+        return false;
+    }
+    else
+    {
+        pj_free(projCheck);
+        return true;
+    }
 }
