@@ -32,11 +32,14 @@ class CDlgProjWizzard : public QDialog, private Ui::IDlgProjWizzard
         CDlgProjWizzard(QLineEdit& line, QWidget * parent);
         virtual ~CDlgProjWizzard();
 
+        static bool validProjStr(const QString projStr);
+
     public slots:
         void accept();
         void slotChange();
 
     private:
+        void findDatum(const QString& str);
         QLineEdit& line;
 };
 #endif                           //CDLGPROJWIZZARD_H
