@@ -1221,290 +1221,3 @@ void CGarminTile::loadPolygonsOfType(polytype_t& polygons, quint16 type, unsigne
 }
 
 
-#ifdef SQL_SEARCH_GARMIN
-void CGarminTile::createIndex(QSqlDatabase& db)
-{
-    //  fprintf(stderr, "createIndex %s\n", qPrintable(filename));
-    QFile file(filename);
-    if(!file.open(QIODevice::ReadOnly))
-    {
-        return;
-    }
-
-    QSqlQuery query(db);
-
-    QMap<QString,subfile_desc_t>::const_iterator subfile = subfiles.begin();
-    while(subfile != subfiles.end())
-    {
-        quint8 level = subfile->maplevels.last().level;
-
-        query.prepare("INSERT INTO subfiles (name, filename) VALUES (:name, :filename)");
-        query.bindValue(":name", subfile.key());
-        query.bindValue(":filename", filename);
-        if(!query.exec())
-        {
-            qDebug() << query.lastError();
-        }
-
-        query.prepare("Select id FROM subfiles WHERE filename = :filename");
-        query.bindValue(":filename", filename);
-        if(!query.exec())
-        {
-            qDebug() << query.lastError();
-        }
-        query.next();
-        quint32 idSubfile = query.value(0).toUInt();
-
-        QByteArray rgndata;
-        readFile(file, subfile->parts["RGN"].offset, subfile->parts["RGN"].size, rgndata);
-
-        const QVector<subdiv_desc_t>&  subdivs = subfile->subdivs;
-        // collect polylines
-        QVector<subdiv_desc_t>::const_iterator subdiv = subdivs.begin();
-        while(subdiv != subdivs.end())
-        {
-
-            if(subdiv->level != level)
-            {
-                ++subdiv;
-                continue;
-            }
-
-            createIndexSubDiv(file, idSubfile, *subdiv, subfile->strtbl, rgndata, db);
-
-            ++subdiv;
-        }
-
-        ++subfile;
-    }
-}
-
-
-void CGarminTile::createIndexSubDiv(QFile& file, quint32 idSubfile, const subdiv_desc_t& subdiv, IGarminStrTbl * strtbl, const QByteArray& rgndata, QSqlDatabase& db)
-{
-    if(subdiv.rgn_start == subdiv.rgn_end) return;
-
-    const quint8 * pRawData = (quint8*)rgndata.data();
-
-    quint32 opnt = 0, oidx = 0, opline = 0, opgon = 0;
-    quint32 objCnt = subdiv.hasIdxPoints + subdiv.hasPoints + subdiv.hasPolylines + subdiv.hasPolygons;
-
-    quint16 * pOffset = (quint16*)(pRawData + subdiv.rgn_start);
-
-    // test for points
-    if(subdiv.hasPoints)
-    {
-        opnt = (objCnt - 1) * sizeof(quint16) + subdiv.rgn_start;
-    }
-    // test for indexed points
-    if(subdiv.hasIdxPoints)
-    {
-        if(opnt)
-        {
-            oidx = gar_load(uint16_t, *pOffset);
-            oidx += subdiv.rgn_start;
-            ++pOffset;
-        }
-        else
-        {
-            oidx = (objCnt - 1) * sizeof(quint16) + subdiv.rgn_start;
-        }
-
-    }
-    // test for polylines
-    if(subdiv.hasPolylines)
-    {
-        if(opnt || oidx)
-        {
-            opline = gar_load(uint16_t, *pOffset);
-            opline += subdiv.rgn_start;
-            ++pOffset;
-        }
-        else
-        {
-            opline = (objCnt - 1) * sizeof(quint16) + subdiv.rgn_start;
-        }
-    }
-    // test for polygons
-    if(subdiv.hasPolygons)
-    {
-        if(opnt || oidx || opline)
-        {
-            opgon = gar_load(uint16_t, *pOffset);
-            opgon += subdiv.rgn_start;
-            ++pOffset;
-        }
-        else
-        {
-            opgon = (objCnt - 1) * sizeof(quint16) + subdiv.rgn_start;
-        }
-    }
-
-#ifdef DEBUG_SHOW_POLY_DATA
-    qDebug() << "--- Subdivision" << subdiv.n << "---";
-    qDebug() << "adress:" << hex << subdiv.rgn_start << "- " << subdiv.rgn_end;
-    qDebug() << "points:            " << hex << opnt;
-    qDebug() << "indexed points:    " << hex << oidx;
-    qDebug() << "polylines:         " << hex << opline;
-    qDebug() << "polygons:          " << hex << opgon;
-#endif                       // DEBUG_SHOW_POLY_DATA
-
-    const quint8 *  pData;
-    const quint8 *  pEnd;
-
-    // decode polylines
-    if(subdiv.hasPolylines)
-    {
-        pData = pRawData + opline;
-        pEnd  = pRawData + (opgon ? opgon : subdiv.rgn_end);
-        while(pData < pEnd)
-        {
-            CGarminPolygon p;
-            quint32 offset = pData - pRawData;
-
-            pData += p.decode(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, true, pData, pEnd);
-            if(strtbl && !p.lbl_in_NET && p.lbl_info)
-            {
-                strtbl->get(file, p.lbl_info,IGarminStrTbl::norm, p.labels);
-            }
-            else if(strtbl && p.lbl_in_NET && p.lbl_info)
-            {
-                strtbl->get(file, p.lbl_info,IGarminStrTbl::net, p.labels);
-            }
-
-            if(!p.labels.isEmpty() && !(0x20 <= p.type && p.type <= 0x25))
-            {
-                double lon1 = p.u[0];
-                double lat1 = p.v[0];
-                double lon2 = lon1;
-                double lat2 = lat1;
-                const int size = p.u.size();
-                for(int i = 0; i < size; ++i)
-                {
-                    const double u = p.u[i];
-                    const double v = p.v[i];
-                    if(u < lon1) lon1 = u;
-                    if(u > lon2) lon2 = u;
-                    if(v > lat1) lat1 = v;
-                    if(v < lat2) lat2 = v;
-                }
-
-                QSqlQuery query(db);
-                query.prepare(QString("INSERT INTO polylines (type, subfile, subdiv, offset, lon1, lat1, lon2, lat2, label) VALUES (%1, %2, %3, %4, %5, %6, %7, %8, :label)").arg(p.type).arg(idSubfile).arg(subdiv.n).arg(offset).arg(lon1).arg(lat1).arg(lon2).arg(lat2));
-                query.bindValue(":label", p.labels.join(" ").simplified());
-                if(!query.exec())
-                {
-                    qDebug() << query.lastError();
-                    qDebug() << query.lastQuery();
-                }
-            }
-        }
-    }
-
-    // decode indexed points
-    if(subdiv.hasIdxPoints)
-    {
-        pData = pRawData + oidx;
-        pEnd  = pRawData + (opline ? opline : opgon ? opgon : subdiv.rgn_end);
-        while(pData < pEnd)
-        {
-            CGarminPoint p;
-            quint32 offset = pData - pRawData;
-
-            pData += p.decode(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, pData);
-            if(strtbl)
-            {
-                p.isLbl6 ? strtbl->get(file, p.lbl_ptr, IGarminStrTbl::poi, p.labels) : strtbl->get(file, p.lbl_ptr, IGarminStrTbl::norm, p.labels);
-            }
-
-            if(!p.labels.isEmpty())
-            {
-                QSqlQuery query(db);
-                query.prepare(QString("INSERT INTO points (type, subfile, subdiv, offset, lon1, lat1, label) VALUES (%1, %2, %3, %4, %5, %6, :label)").arg(p.type).arg(idSubfile).arg(subdiv.n).arg(offset).arg(p.lon).arg(p.lat));
-                query.bindValue(":label", p.labels.join(" ").simplified());
-                if(!query.exec())
-                {
-                    qDebug() << query.lastError();
-                    qDebug() << query.lastQuery();
-                }
-            }
-        }
-    }
-
-    // decode points
-    if(subdiv.hasPoints)
-    {
-        pData = pRawData + opnt;
-        pEnd  = pRawData + (oidx ? oidx : opline ? opline : opgon ? opgon : subdiv.rgn_end);
-        while(pData < pEnd)
-        {
-            CGarminPoint p;
-            quint32 offset = pData - pRawData;
-
-            pData += p.decode(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, pData);
-            if(strtbl)
-            {
-                p.isLbl6 ? strtbl->get(file, p.lbl_ptr, IGarminStrTbl::poi, p.labels) : strtbl->get(file, p.lbl_ptr, IGarminStrTbl::norm, p.labels);
-            }
-            if(!p.labels.isEmpty())
-            {
-                QSqlQuery query(db);
-                query.prepare(QString("INSERT INTO points (type, subfile, subdiv, offset, lon1, lat1, label) VALUES (%1, %2, %3, %4, %5, %6, :label)").arg(p.type).arg(idSubfile).arg(subdiv.n).arg(offset).arg(p.lon).arg(p.lat));
-                query.bindValue(":label", p.labels.join(" ").simplified());
-                if(!query.exec())
-                {
-                    qDebug() << query.lastError();
-                    qDebug() << query.lastQuery();
-                }
-            }
-        }
-    }
-
-}
-
-
-void CGarminTile::readPolyline(const QString& subfile, quint32 n, quint32 offset, polytype_t& polylines)
-{
-    //  fprintf(stderr, "readPolyline %s\n", qPrintable(filename));
-    QFile file(filename);
-    if(!file.open(QIODevice::ReadOnly))
-    {
-        return;
-    }
-
-    QByteArray rgndata;
-    readFile(file, subfiles[subfile].parts["RGN"].offset, subfiles[subfile].parts["RGN"].size, rgndata);
-    subdiv_desc_t& subdiv = subfiles[subfile].subdivs[n];
-
-    const quint8 *  pData = (quint8*)rgndata.data() + offset;
-
-    polylines.push_back(CGarminPolygon());
-    CGarminPolygon& p = polylines.last();
-    pData += p.decode(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, true, pData, 0);
-
-    file.close();
-}
-
-
-void CGarminTile::readPoint(const QString& subfile, quint32 n, quint32 offset, pointtype_t& point)
-{
-    //  fprintf(stderr, "readPoint %s\n", qPrintable(filename));
-    QFile file(filename);
-    if(!file.open(QIODevice::ReadOnly))
-    {
-        return;
-    }
-
-    QByteArray rgndata;
-    readFile(file, subfiles[subfile].parts["RGN"].offset, subfiles[subfile].parts["RGN"].size, rgndata);
-    subdiv_desc_t& subdiv = subfiles[subfile].subdivs[n];
-
-    const quint8 *  pData = (quint8*)rgndata.data() + offset;
-
-    point.push_back(CGarminPoint());
-    CGarminPoint& p = point.last();
-    pData += p.decode(subdiv.iCenterLng, subdiv.iCenterLat, subdiv.shift, pData);
-
-    file.close();
-}
-#endif                           //SQL_SEARCH_GARMIN
