@@ -39,6 +39,7 @@
 #include "CMenus.h"
 #include "IDevice.h"
 #include "CDlgScreenshot.h"
+#include "CDlgLoadOnlineMap.h"
 #include "CUndoStack.h"
 #include "WptIcons.h"
 #include "CAppOpts.h"
@@ -51,6 +52,7 @@
 #include "CGridDB.h"
 #include "CDlgSetupGrid.h"
 #include "CSettings.h"
+#include "version.h"
 
 #include <QtGui>
 #ifndef WIN32
@@ -74,7 +76,6 @@ CMainWindow::CMainWindow()
     setupMenu = 0;
     setObjectName("MainWidget");
     setWindowTitle("QLandkarte GT");
-//    setWindowIcon(QIcon(":/icons/iconGlobe16x16.png"));
     setAcceptDrops(true);
 
     initWptIcons();
@@ -207,9 +208,6 @@ CMainWindow::CMainWindow()
 #ifdef HAS_DBUS
     actionGroupProvider->addAction(CMenus::MainMoreMenu, "aOcm");
 #endif
-
-
-
     actionGroupProvider->addAction(CMenus::RouteMenu, "aSwitchToMain");
     actionGroupProvider->addAction(CMenus::RouteMenu, "aMoveArea");
     actionGroupProvider->addAction(CMenus::RouteMenu, "aZoomArea");
@@ -217,8 +215,6 @@ CMainWindow::CMainWindow()
     actionGroupProvider->addAction(CMenus::RouteMenu, "aUploadRoute");
     actionGroupProvider->addAction(CMenus::RouteMenu, "aDownloadRoute");
 
-
-
     connect(actionGroupProvider, SIGNAL(stateChanged()),megaMenu , SLOT(switchState()));
 
     switchState();
@@ -234,7 +230,6 @@ CMainWindow::CMainWindow()
     summary->setAlignment(Qt::AlignJustify|Qt::AlignTop);
     //
     ltmp->addWidget(summary);
-
     ltmp->addWidget(new QLabel(tr("<b>GPS Device:</b>"), wtmp));
 
     comboDevice = new QComboBox(wtmp);
@@ -282,6 +277,8 @@ CMainWindow::CMainWindow()
         geodb       = new CGeoDB(tabbar, this);
     }
 
+    canvas->setupDelayed();
+
     connect(searchdb, SIGNAL(sigChanged()), canvas, SLOT(update()));
     connect(wptdb, SIGNAL(sigChanged()), canvas, SLOT(update()));
     connect(trackdb, SIGNAL(sigChanged()), canvas, SLOT(update()));
@@ -298,7 +295,6 @@ CMainWindow::CMainWindow()
     connect(overlaydb, SIGNAL(sigModified()), this, SLOT(slotModified()));
     connect(routedb, SIGNAL(sigModified()), this, SLOT(slotModified()));
 
-
     if(geodb)
     {
         geodb->gainFocus();
@@ -403,8 +399,7 @@ CMainWindow::CMainWindow()
 
     connect(&CTrackDB::self(), SIGNAL(sigHighlightTrack(CTrack *)), canvas, SLOT(slotHighlightTrack(CTrack*)));
     connect(&CTrackDB::self(), SIGNAL(sigChanged()), canvas, SLOT(slotTrackChanged()));
-
-
+    connect(&soapHttp, SIGNAL(responseReady(const QtSoapMessage &)),this, SLOT(slotGetResponse(const QtSoapMessage &)));
 }
 
 
@@ -557,6 +552,7 @@ void CMainWindow::setupMenuBar()
     menu = new QMenu(this);
     menu->setTitle(tr("&File"));
     menu->addAction(QIcon(":/icons/iconOpenMap16x16.png"),tr("Load Map"),this,SLOT(slotLoadMapSet()));
+    menu->addAction(QIcon(":/icons/iconOpenMap16x16.png"),tr("Load Online Map"),this,SLOT(slotLoadOnlineMapSet()));
     menu->addSeparator();
     menu->addAction(QIcon(":/icons/iconFileLoad16x16.png"),tr("Load Geo Data"),this,SLOT(slotLoadData()), Qt::CTRL + Qt::Key_L);
     menu->addAction(QIcon(":/icons/iconFileSave16x16.png"),tr("Save Geo Data"),this,SLOT(slotSaveData()), Qt::CTRL + Qt::Key_S);
@@ -643,6 +639,7 @@ void CMainWindow::setupMenuBar()
     menu->addAction(QIcon(":/icons/iconHelp16x16.png"),tr("http://Help"),this,SLOT(slotHelp()));
     menu->addAction(QIcon(":/icons/iconHelp16x16.png"),tr("http://Support"),this,SLOT(slotSupport()));
     menu->addSeparator();
+    slotUpdate();
     menu->addAction(QIcon(":/icons/iconGlobe16x16.png"),tr("About &QLandkarte GT"),this,SLOT(slotCopyright()));
 
 #endif
@@ -699,6 +696,19 @@ void CMainWindow::slotLoadMapSet()
     cfg.setValue("maps/filter",filter);
 }
 
+void CMainWindow::slotLoadOnlineMapSet()
+{
+    CDlgLoadOnlineMap dlg;
+    dlg.exec();
+
+    QString filename = dlg.selectedfile;
+
+    if(filename.isEmpty()) return;
+
+    CResources::self().pathMaps = QFileInfo(filename).absolutePath();
+    CMapDB::self().openMap(filename, false, *canvas);
+}
+
 
 void CMainWindow::slotCopyright()
 {
@@ -1520,6 +1530,39 @@ void CMainWindow::slotSupport()
     QDesktopServices::openUrl(QUrl("http://www.qlandkarte.org/index.php?option=com_content&view=article&id=17&Itemid=19"));
 }
 
+void CMainWindow::slotDownload()
+{
+    QDesktopServices::openUrl(QUrl("http://www.qlandkarte.org/index.php?option=com_content&view=article&id=17&Itemid=19"));
+}
+
+void CMainWindow::slotUpdate()
+{
+    QtSoapMessage request;
+    request.setMethod(QtSoapQName("getlastversion", "urn:qlandkartegt"));
+    request.addMethodArgument("changelog", "", "0");
+    soapHttp.setHost("www.qlandkarte.org");
+    soapHttp.submitRequest(request, "/webservice/qlandkartegt.php");
+}
+
+void CMainWindow::slotGetResponse(const QtSoapMessage &message)
+{
+    if (message.isFault())
+    {
+        qDebug("Error: %s", qPrintable(message.faultString().toString()));
+    }
+    else
+    {
+        //qDebug("message : %s",qPrintable(message.toXmlString(1)));
+        QString res = message.returnValue().toString();
+        res = res.simplified();
+        if (!res.isEmpty() && res != VER_STR)
+        {
+            statusBar()->showMessage(tr("New QLandkarte GT %1 available").arg(res),0);
+            qDebug("Version is: %s", res.toLatin1().constData());
+        }
+    }
+}
+
 void CMainWindow::slotToggleToolView()
 {
     qDebug() << "CMainWindow::slotToggleToolView()";
