@@ -21,6 +21,7 @@
 #define CMAINWINDOW_H
 
 #include <QMainWindow>
+#include <qtsoap.h>
 class QSplitter;
 class QLabel;
 class QTabWidget;
@@ -86,6 +87,7 @@ class CMainWindow : public QMainWindow
         void slotReloadArgs();
         void switchState();
         void slotLoadMapSet();
+        void slotLoadOnlineMapSet();
         void slotCopyright();
         void slotToolBoxChanged(int idx);
         void slotConfig();
@@ -108,8 +110,11 @@ class CMainWindow : public QMainWindow
         void slotFAQ();
         void slotHelp();
         void slotSupport();
+        void slotUpdate();
+        void slotDownload();
 
         void slotToggleToolView();
+        void slotGetResponse(const QtSoapMessage &);
 
     private:
         friend class CDBus;
@@ -198,6 +203,9 @@ class CMainWindow : public QMainWindow
 
         QCheckBox * quadraticZoom;
 
+        QtSoapHttpTransport soapHttp;
+
+
 };
 
 extern CMainWindow * theMainWindow;
