@@ -30,10 +30,16 @@
 #include "CWpt.h"
 #include "CWptDB.h"
 #include "WptIcons.h"
+#include "CSettings.h"
 
-#include <GL/glu.h>
 #include <QtGui>
+#include <QtOpenGL>
 #include <math.h>
+#if defined(Q_WS_MAC)
+#include <OpenGL/glu.h>
+#else
+#include <GL/glu.h>
+#endif
 
 #ifndef GL_CLAMP_TO_EDGE
 #define GL_CLAMP_TO_EDGE 0x812F
@@ -160,7 +166,7 @@ CMap3D::CMap3D(IMap * map, QWidget * parent)
     actTrackMode->setChecked(false);
     connect(actTrackMode, SIGNAL(triggered()), this, SLOT(slotTrackModeChanged()));
 
-    QSettings cfg;
+    SETTINGS;
     act3DMap->setChecked(cfg.value("map/3D/3dmap", true).toBool());
     actFPVMode->setChecked(cfg.value("map/3D/fpv", true).toBool());
     actTrackOnMap->setChecked(cfg.value("map/3D/trackonmap", false).toBool());
@@ -200,7 +206,7 @@ CMap3D::~CMap3D()
     glDeleteLists(mapObjectId, 1);
     glDeleteLists(trkObjectId, 1);
 
-    QSettings cfg;
+    SETTINGS;
     cfg.setValue("map/3D/3dmap", act3DMap->isChecked());
     cfg.setValue("map/3D/fpv", actFPVMode->isChecked());
     cfg.setValue("map/3D/trackonmap", actTrackOnMap->isChecked());
@@ -332,7 +338,7 @@ void CMap3D::slotTrackModeChanged()
         double x0 = xpos;
         double y0 = ypos;
         double z0 = zpos;
-        XY p;
+        projXY p;
         CTrack::pt_t selTrkPt;
 
         convert3D2Pt(x0, y0, z0);
@@ -615,7 +621,7 @@ void CMap3D::setTrackObject()
 
     if (track != 0)
     {
-        XY pt1, pt2;
+        projXY pt1, pt2;
 
         glLineWidth(5.0);
         highBorderColor = track->getColor();
@@ -994,7 +1000,7 @@ void CMap3D::draw3DMap()
     double current_step_x = w / (double) (xcount - 1);
     double current_step_y = h / (double) (ycount - 1);
 
-    int ix=0, iy, iv, it, j, k, end;
+    int ix=0, iy, iv, it, j, k;
     double x, y, u, v;
     GLuint idx[4];
 
@@ -1032,7 +1038,7 @@ void CMap3D::draw3DMap()
          */
         iv = iv % (xcount * 3 * 2);
         it = it % (xcount * 2 * 2);
-        end = ix + xcount;
+
         for (x = 0, ix = 0; ix < xcount; x += current_step_x, iv += 3, it += 2, ix++)
         {
             vertices[iv + 0] = x;
@@ -1113,7 +1119,7 @@ void CMap3D::quadTexture(GLdouble x, GLdouble y, GLdouble xsize, GLdouble ysize,
 
 void CMap3D::drawWaypoints()
 {
-    const QSize mapSize = theMap->getSize();
+
     const double wsize = 5;
 
     GLint iconId, iconMaskId, textId, textMaskId;
@@ -1490,7 +1496,7 @@ void CMap3D::mousePressEvent(QMouseEvent *e)
                 diff = (zRotation - 180)* 2;
             }
 
-            zRotation = atan(ypos/xpos)/PI * 180;
+            zRotation = atan(ypos/xpos)/M_PI * 180;
 
             //            qDebug() << "---------"  << zRotation << xpos << ypos;
 
@@ -1504,8 +1510,8 @@ void CMap3D::mousePressEvent(QMouseEvent *e)
             //            qDebug() << "<<<<<<<<<"  << zRotation << xpos << ypos;
 
             double r = sqrt(xpos*xpos + ypos*ypos);
-            xpos = -r*sin(zRotation/180 * PI);
-            ypos = -r*cos(zRotation/180 * PI);
+            xpos = -r*sin(zRotation/180 * M_PI);
+            ypos = -r*cos(zRotation/180 * M_PI);
 
             update();
         }
@@ -1550,8 +1556,8 @@ void CMap3D::mouseMoveEvent(QMouseEvent *event)
             if(!actFPVMode->isChecked())
             {
                 double r = sqrt(xpos*xpos + ypos*ypos);
-                xpos = -r*sin(zRotation/180 * PI);
-                ypos = -r*cos(zRotation/180 * PI);
+                xpos = -r*sin(zRotation/180 * M_PI);
+                ypos = -r*cos(zRotation/180 * M_PI);
             }
         }
         update();
@@ -1596,6 +1602,8 @@ void CMap3D::keyPressEvent ( QKeyEvent * e )
 {
     bool changePOV2Track = false;
 
+    qDebug() << hex << e->key();
+
     switch (e->key())
     {
         case Qt::Key_W:
@@ -1611,13 +1619,13 @@ void CMap3D::keyPressEvent ( QKeyEvent * e )
             }
             else
             {
-                double zRotRad = (zRotation / 180 * PI);
+                double zRotRad = (zRotation / 180 * M_PI);
                 xpos += sin(zRotRad) * 4;
                 ypos += cos(zRotRad) * 4;
 
                 if(coupleElePOV)
                 {
-                    double xRotRad = (xRotation / 180 * PI);
+                    double xRotRad = (xRotation / 180 * M_PI);
                     zpos -= sin(xRotRad) * 4;
                     adjustElevationToMap();
                 }
@@ -1638,13 +1646,13 @@ void CMap3D::keyPressEvent ( QKeyEvent * e )
             }
             else
             {
-                double zRotRad = (zRotation / 180 * PI);
+                double zRotRad = (zRotation / 180 * M_PI);
                 xpos -= sin(zRotRad) * 4;
                 ypos -= cos(zRotRad) * 4;
 
                 if(coupleElePOV)
                 {
-                    double xRotRad = (xRotation / 180 * PI);
+                    double xRotRad = (xRotation / 180 * M_PI);
                     zpos += sin(xRotRad) * 4;
                     adjustElevationToMap();
                 }
@@ -1654,7 +1662,7 @@ void CMap3D::keyPressEvent ( QKeyEvent * e )
 
         case Qt::Key_A:
         {
-            double zRotRad = (zRotation / 180 * PI);
+            double zRotRad = (zRotation / 180 * M_PI);
             xpos -= cos(zRotRad) * 4;
             ypos += sin(zRotRad) * 4;
             break;
@@ -1662,12 +1670,21 @@ void CMap3D::keyPressEvent ( QKeyEvent * e )
 
         case Qt::Key_D:
         {
-            double zRotRad = (zRotation / 180 * PI);
+            double zRotRad = (zRotation / 180 * M_PI);
             xpos += cos(zRotRad) * 4;
             ypos -= sin(zRotRad) * 4;
             break;
         }
 
+        case Qt::Key_Asterisk:
+            zoomFactorEle *= 1.1;
+            break;
+
+        case Qt::Key_Underscore:
+            zoomFactorEle /= 1.1;
+            break;
+
+
         default:
             e->ignore();
     }
@@ -1785,6 +1802,21 @@ bool CMap3D::eventFilter(QObject *o, QEvent *e)
         {
             keyLPressed = true;
         }
+        else if(keyEvent->key() == Qt::Key_Plus)
+        {
+            zoomFactor *= 1.1;
+            e->accept();
+            update();
+            return true;
+        }
+        else if(keyEvent->key() == Qt::Key_Minus)
+        {
+            zoomFactor /= 1.1;
+            e->accept();
+            update();
+            return true;
+        }
+
     }
     else if (e->type() == QEvent::KeyRelease)
     {
@@ -1826,7 +1858,7 @@ bool CMap3D::getEleRegion(QVector<float>& eleData, int& xcount, int& ycount)
     double  h = s.height();
 
     IMap& dem = CMapDB::self().getDEM();
-    XY pen1, pen2;
+    projXY pen1, pen2;
     pen1.u = 0;
     pen1.v = 0;
     pen2.u = w;
