@@ -55,7 +55,7 @@ class CMapGeoTiff : public IMap
         GDALDataset * getDataset();
 
     protected:
-        void getArea_n_Scaling(XY& p1, XY& p2, float& my_xscale, float& my_yscale);
+        void getArea_n_Scaling(projXY& p1, projXY& p2, float& my_xscale, float& my_yscale);
 
     private:
         void zoom(qint32& level);
