@@ -32,7 +32,6 @@
 #include "CMainWindow.h"
 #include "CResources.h"
 #include "IDevice.h"
-#include "CDlgCreateWorldBasemap.h"
 #include "CMenus.h"
 #include "CActions.h"
 #ifdef PLOT_3D
@@ -95,47 +94,38 @@ void CMegaMenu::switchByKeyWord(const QString& key)
     else if (key == "Waypoints")
     {
         actions->funcSwitchToWpt();
-        actions->funcMoveArea();
     }
     else if (key == "Search")
     {
         actions->funcSwitchToMain();
-        actions->funcMoveArea();
     }
     else if (key == "Maps")
     {
         actions->funcSwitchToMap();
-        actions->funcMoveArea();
     }
     else if (key == "Tracks")
     {
         actions->funcSwitchToTrack();
-        actions->funcMoveArea();
     }
     else if (key == "LiveLog")
     {
         actions->funcSwitchToLiveLog();
-        actions->funcMoveArea();
     }
     else if (key == "Overlay")
     {
         actions->funcSwitchToOverlay();
-        actions->funcMoveArea();
     }
     else if (key == "OverlayDistance")
     {
         actions->funcSwitchToOverlayDistance();
-        actions->funcMoveArea();
     }
     else if (key == "Routes")
     {
         actions->funcSwitchToRoute();
-        actions->funcMoveArea();
     }
     else if (key == "GeoDB")
     {
         actions->funcSwitchToMain();
-        actions->funcMoveArea();
     }
 
 
@@ -171,7 +161,8 @@ void CMegaMenu::initStyleOption(QStyleOptionMenuItem *option, const QAction *act
     }
     if(!isCurrent)
     {
-        option->palette.setBrush(QPalette::Normal, QPalette::Window, QColor(0,0,0,0));
+        option->palette.setBrush(QPalette::Normal, QPalette::Window, Qt::transparent);
+        option->palette.setBrush(QPalette::Normal, QPalette::Button, Qt::transparent);
     }
 
     if (isEnabled() && action->isEnabled() && (!action->menu() || action->menu()->isEnabled()))
@@ -188,6 +179,9 @@ void CMegaMenu::initStyleOption(QStyleOptionMenuItem *option, const QAction *act
     if (isCurrent && !action->isSeparator())
     {
         option->state |= QStyle::State_Selected | (mouseDown ? QStyle::State_Sunken : QStyle::State_None);
+#ifdef Q_WS_MAC
+        option->palette.setColor(QPalette::Normal, QPalette::HighlightedText, Qt::white);
+#endif
     }
 
     //     option->menuHasCheckableItems = d->hasCheckableItems;
@@ -233,6 +227,7 @@ void CMegaMenu::initStyleOption(QStyleOptionMenuItem *option, const QAction *act
     option->tabWidth        = fm.width("MMMM");
     option->maxIconWidth    = 16;
     option->menuRect        = rect();
+
 }
 
 
@@ -266,14 +261,15 @@ void CMegaMenu::paintEvent(QPaintEvent *e)
 
         QStyleOptionMenuItem opt;
         initStyleOption(&opt, act, currentItemIndex == idx);
-
         opt.rect = rectF[idx];
 
         style()->drawControl(QStyle::CE_MenuItem, &opt, &p, this);
 
         ++idx;
         if (idx >= SIZE_OF_MEGAMENU)
+        {
             break;
+        }
     }
 }
 
@@ -285,9 +281,14 @@ void CMegaMenu::resizeEvent(QResizeEvent * e)
     QFontMetrics fm(f);
 
     int w   = e->size().width();
-    int h   = fm.height();
+    int h   = fm.height()+fm.descent()*2;
     yoff    = 0;
 
+    if(h < 16+2)
+    {
+        h = 16+2;
+    }
+
     rectTitle = QRect(0,yoff, w, h);
     for(int i=0; i < SIZE_OF_MEGAMENU; ++i)
     {
