@@ -18,9 +18,9 @@
 #include "CMainWindow.h"
 #include "CActions.h"
 #include "CCanvas.h"
+#include "CMegaMenu.h"
 
 #include <QtGui>
-#define SIZE_OF_MEGAMENU 11
 
 // #define lqdebug(x) qDebug() << x
 #define lqdebug(x)
