@@ -52,8 +52,7 @@ void CMouseAddWpt::mousePressEvent(QMouseEvent * e)
     double v = e->pos().y();
     map.convertPt2Rad(u,v);
     float ele = dem.getElevation(u,v);
-    CWptDB::self().newWpt(u, v, ele, "");
-
+    CWptDB::self().newWpt(u, v, ele, CWptDB::self().getNewWptName());
 }
 
 
