@@ -52,13 +52,17 @@ class CMouseMoveMap : public IMouse
         void slotAddWpt();
         void slotCopyPositionTrack();
         void slotEditTrack();
-		void slotOpenGoogleMaps();	//TODO: GOOGLE MAPS
+        void slotSplitTrack();
+        void slotOpenGoogleMaps();	//TODO: GOOGLE MAPS
 
         void slotCopyPosDegree();
+        void slotCopyPosGrid();
         void slotCopyPosMeter();
         void slotCopyPosPixel();
         void slotCopyPosPixelSize();
 
+        void slotReloadMap();
+
     private:
         /// true if left mouse button is pressed
         bool moveMap;
