@@ -25,7 +25,7 @@
 #include "COverlayDistance.h"
 
 #include <QMap>
-#include <projects.h>
+#include <proj_api.h>
 #ifdef __MINGW32__
 #undef LP
 #endif
