@@ -1208,11 +1208,11 @@ void COverlayDistance::slotToTrack()
 
     if(eleMode == CDlgConvertToTrack::eLocal)
     {
-        track->replaceElevationByLocal();
+        track->replaceElevationByLocal(true);
     }
     else if(eleMode == CDlgConvertToTrack::eRemote)
     {
-        track->replaceElevationByRemote();
+        track->replaceElevationByRemote(true);
     }
 
     CTrackDB::self().addTrack(track, false);
