@@ -33,7 +33,7 @@ class COverlayText : public IOverlay
         virtual ~COverlayText();
 
         bool isCloseEnough(const QPoint& pt);
-        void draw(QPainter& p);
+        void draw(QPainter& p, const QRect& viewport);
 
         void mouseMoveEvent(QMouseEvent * e);
         void mousePressEvent(QMouseEvent * e);
@@ -46,6 +46,8 @@ class COverlayText : public IOverlay
 
         QString getInfo();
 
+        QString getName(){return getInfo();}
+
     private:
         friend class COverlayDB;
         QRect rect;
@@ -62,8 +64,6 @@ class COverlayText : public IOverlay
         bool doSize;
 
         bool doSpecialCursor;
-
-        QString sometext;
         QTextDocument * doc;
 };
 #endif                           //COVERLAYTEXT_H
