@@ -33,9 +33,9 @@ class COverlayTextBox : public IOverlay
         COverlayTextBox(const QString& text, double lon, double lat, const QPoint& anchor, const QRect& rect, QObject * parent);
         virtual ~COverlayTextBox();
 
-        void draw(QPainter& p);
+        void draw(QPainter& p, const QRect& viewport);
 
-        static QPolygon makePolyline(const QPoint& anchor, const QRect& r);
+        static QPolygonF makePolyline(const QPoint& anchor, const QRect& r);
 
         bool isCloseEnough(const QPoint& pt);
 
@@ -50,6 +50,8 @@ class COverlayTextBox : public IOverlay
 
         QString getInfo();
 
+        QString getName(){return getInfo();}
+
         void makeVisible();
 
         QRectF getBoundingRectF();
@@ -65,7 +67,7 @@ class COverlayTextBox : public IOverlay
         /// the anchor point [px]
         QPoint pt;
         /// the resulting polylin, normalized to the anchor point
-        QPolygon polyline;
+        QPolygonF polyline;
 
         QRect rectMove;
         QRect rectSize;
@@ -75,7 +77,6 @@ class COverlayTextBox : public IOverlay
 
         QRect rectDoc;
 
-        QString text;
         QTextDocument * doc;
 
         bool doMove;
