@@ -19,9 +19,12 @@
 #include "CSearch.h"
 
 CSearch::CSearch(QObject * parent)
-: QObject(parent)
+: IItem(parent)
+, lon(0.0)
+, lat(0.0)
 {
-
+    iconPixmap = QPixmap(":/icons/iconBullseye16x16.png");
+    iconString = "Bullseye";
 }
 
 
@@ -29,3 +32,35 @@ CSearch::~CSearch()
 {
 
 }
+
+QString CSearch::getInfo()
+{
+    QString str;
+
+    if(!street.isEmpty())
+    {
+        str = street;
+    }
+
+    if(!municipal.isEmpty())
+    {
+        if(!str.isEmpty()) str += ", ";
+        if(!postalCode.isEmpty()) str += postalCode + " ";
+
+        str += municipal;
+    }
+
+    if(!country.isEmpty())
+    {
+        if(!str.isEmpty()) str += ", ";
+        str += country;
+    }
+
+    if(!countryCode.isEmpty())
+    {
+        if(!str.isEmpty()) str += ", ";
+        str += "(" + countryCode.toUpper() + ")";
+    }
+
+    return str.isEmpty() ? name : str;
+}
