@@ -22,8 +22,9 @@
 #include <QtGui>
 #include <limits>
 
-#if WIN32
 #include <math.h>
+
+#if WIN32
 #include <float.h>
 #ifndef __MINGW32__
 typedef __int32 int32_t;
@@ -82,10 +83,14 @@ QRegExp reCoord2("^\\s*([N|S]){1}\\s*([0-9]+\\.[0-9]+)\\W*\\s+([E|W|O]){1}\\s*([
 QRegExp reCoord3("^\\s*([-0-9]+\\.[0-9]+)\\s+([-0-9]+\\.[0-9]+)\\s*$");
 
 QRegExp reCoord4("^\\s*([N|S]){1}\\s*([0-9]+)\\W+([0-9]+)\\W+([0-9]+)\\W*([E|W|O]){1}\\W*([0-9]+)\\W+([0-9]+)\\W+([0-9]+)\\W*\\s*$");
+
+QRegExp reCoord5("^\\s*([-0-9]+\\.[0-9]+)([N|S])\\s+([-0-9]+\\.[0-9]+)([W|E])\\s*$");
 }
 
 using namespace GeoMath;
 
+//49.03196968ºN 12.10440376ºE
+
 bool GPS_Math_Str_To_Deg(const QString& str, float& lon, float& lat, bool silent)
 {
 
@@ -136,6 +141,16 @@ bool GPS_Math_Str_To_Deg(const QString& str, float& lon, float& lat, bool silent
         GPS_Math_DegMinSec_To_Deg(signLon, degLon, minLon, secLon, lon);
 
 
+    }
+    else if(reCoord5.exactMatch(str))
+    {
+        bool signLon    = reCoord4.cap(4) == "W";
+        bool signLat    = reCoord4.cap(2) == "S";
+        lat             = reCoord5.cap(1).toDouble();
+        lon             = reCoord5.cap(3).toDouble();
+
+        if(signLon) lon = -lon;
+        if(signLat) lat = -lat;
     }
     else
     {
@@ -188,13 +203,13 @@ bool testLineSegForIntersect(float x11, float y11, float x12, float y12, float x
 }
 
 
-bool testPointInPolygon(const XY& pt, const QVector<XY>& poly1)
+bool testPointInPolygon(const projXY& pt, const QVector<projXY>& poly1)
 {
 
     bool    c = false;
     int     npol;
     int     i = 0, j = 0;
-    XY      p1, p2;              // the two points of the polyline close to pt
+    projXY      p1, p2;              // the two points of the polyline close to pt
     float  x = pt.u;
     float  y = pt.v;
 
@@ -219,7 +234,7 @@ bool testPointInPolygon(const XY& pt, const QVector<XY>& poly1)
 }
 
 
-bool testPolygonsForIntersect(const QVector<XY>& poly1, const QVector<XY>& poly2)
+bool testPolygonsForIntersect(const QVector<projXY>& poly1, const QVector<projXY>& poly2)
 {
 
     int n;
@@ -238,7 +253,7 @@ bool testPolygonsForIntersect(const QVector<XY>& poly1, const QVector<XY>& poly2
     int i1 = 0, j1 = 0;
     int i2 = 0, j2 = 0;
 
-    XY  p1, p2, p3, p4;
+    projXY  p1, p2, p3, p4;
 
     for (i1 = 0, j1 = npol1-1; i1 < npol1; j1 = i1++)
     {
@@ -260,7 +275,7 @@ bool testPolygonsForIntersect(const QVector<XY>& poly1, const QVector<XY>& poly2
 
 // from http://www.movable-type.co.uk/scripts/LatLongVincenty.html
 // additional antipodal convergence trick might be a bit lame, but it seems to work
-double distance(const XY& p1, const XY& p2, double& a1, double& a2)
+double distance(const projXY& p1, const projXY& p2, double& a1, double& a2)
 {
     double cosSigma = 0.0;
     double sigma = 0.0;
@@ -277,14 +292,14 @@ double distance(const XY& p1, const XY& p2, double& a1, double& a2)
     double U2 = atan((1-WGS84_f) * tan(p2.v));
     double sinU1 = sin(U1), cosU1 = cos(U1);
     double sinU2 = sin(U2), cosU2 = cos(U2);
-    double lambda = L, lambdaP = (double)(2*PI);
+    double lambda = L, lambdaP = (double)(2*M_PI);
     unsigned iterLimit = 20;
 
     while (fabs(lambda - lambdaP) > 1e-12)
     {
         if (!iterLimit)
         {
-            lambda = PI;
+            lambda = M_PI;
             qDebug() << "No lambda convergence, most likely due to near-antipodal points. Assuming antipodal.";
         }
 
@@ -320,13 +335,13 @@ double distance(const XY& p1, const XY& p2, double& a1, double& a2)
     double deltaSigma = B*sinSigma*(cos2SigmaM+B/4*(cosSigma*(-1+2*cos2SigmaM*cos2SigmaM)-B/6*cos2SigmaM*(-3+4*sinSigma*sinSigma)*(-3+4*cos2SigmaM*cos2SigmaM)));
     double s = WGS84_b*A*(sigma-deltaSigma);
 
-    a1 = atan2(cosU2 * sinLambda, cosU1 * sinU2 - sinU1 * cosU2 * cosLambda) * 360 / TWOPI;
-    a2 = atan2(cosU1 * sinLambda, -sinU1 * cosU2 + cosU1 * sinU2 * cosLambda) * 360 / TWOPI;
+    a1 = atan2(cosU2 * sinLambda, cosU1 * sinU2 - sinU1 * cosU2 * cosLambda) * 360 / (2*M_PI);
+    a2 = atan2(cosU1 * sinLambda, -sinU1 * cosU2 + cosU1 * sinU2 * cosLambda) * 360 / (2*M_PI);
     return s;
 }
 
 
-double parallel_distance(const XY& p1, const XY& p2)
+double parallel_distance(const projXY& p1, const projXY& p2)
 {
     // Assure same latitude V
     if (p1.v != p2.v) return std::numeric_limits<double>::quiet_NaN();
@@ -362,7 +377,7 @@ bool GPS_Math_Str_To_LongLat(const QString& str, float& lon, float& lat, const Q
     double u = 0, v = 0;
     QRegExp re("^\\s*([\\-0-9\\.]+)\\s+([\\-0-9\\.]+)\\s*$");
 
-    PJ * pjTar = 0;
+    projPJ  pjTar = 0;
     if(!tarproj.isEmpty())
     {
         pjTar = pj_init_plus(tarproj.toLatin1());
@@ -373,7 +388,7 @@ bool GPS_Math_Str_To_LongLat(const QString& str, float& lon, float& lat, const Q
         }
     }
 
-    PJ * pjSrc = 0;
+    projPJ  pjSrc = 0;
     if(!srcproj.isEmpty())
     {
         pjSrc = pj_init_plus(srcproj.toLatin1());
@@ -392,12 +407,8 @@ bool GPS_Math_Str_To_LongLat(const QString& str, float& lon, float& lat, const Q
 
     if(GPS_Math_Str_To_Deg(str, lon, lat,true))
     {
-        if(pjTar)
-        {
-            u = lon * DEG_TO_RAD;
-            v = lat * DEG_TO_RAD;
-            pj_transform(pjSrc,pjTar,1,0,&u,&v,0);
-        }
+        u = lon * DEG_TO_RAD;
+        v = lat * DEG_TO_RAD;
     }
     else
     {
@@ -434,16 +445,16 @@ bool GPS_Math_Str_To_LongLat(const QString& str, float& lon, float& lat, const Q
 }
 
 
-XY GPS_Math_Wpt_Projection(const XY& pt1, double distance, double bearing)
+projXY GPS_Math_Wpt_Projection(const projXY& pt1, double distance, double bearing)
 {
-    XY pt2;
+    projXY pt2;
 
     double d    = distance / 6378130.0;
     double lon1 = pt1.u;
     double lat1 = pt1.v;
 
     double lat2 = asin(sin(lat1) * cos(d) + cos(lat1) * sin(d) * cos(-bearing));
-    double lon2 = cos(lat1) == 0 ? lon1 : fmod(lon1 - asin(sin(-bearing) * sin(d) / cos(lat1)) + PI, TWOPI) - PI;
+    double lon2 = cos(lat1) == 0 ? lon1 : fmod(lon1 - asin(sin(-bearing) * sin(d) / cos(lat1)) + M_PI, (2*M_PI)) - M_PI;
 
     pt2.u = lon2;
     pt2.v = lat2;
@@ -454,7 +465,7 @@ XY GPS_Math_Wpt_Projection(const XY& pt1, double distance, double bearing)
 extern void GPS_Math_SubPolyline( const QPoint& pt1, const QPoint& pt2, int threshold, const QPolygon& line1, QPolygon& line2)
 {
     int i, len;
-    XY p1, p2;
+    projXY p1, p2;
     double dx,dy;                // delta x and y defined by p1 and p2
     double d_p1_p2;              // distance between p1 and p2
     double u;                    // ratio u the tangent point will divide d_p1_p2
@@ -462,7 +473,7 @@ extern void GPS_Math_SubPolyline( const QPoint& pt1, const QPoint& pt2, int thre
     double distance;     // the distance to the polyline
     double shortest1 = threshold;
     double shortest2 = threshold;
-    int idx11 = -1, idx21 = -1, idx12 = -1, idx22 = -1;;
+    int idx11 = -1, idx21 = -1, idx12 = -1;
 
     QPoint pt11;
     QPoint pt21;
@@ -519,7 +530,6 @@ extern void GPS_Math_SubPolyline( const QPoint& pt1, const QPoint& pt2, int thre
             if(distance < shortest2)
             {
                 idx21 = i - 1;
-                idx22 = i;
                 pt21.setX(x);
                 pt21.setY(y);
                 shortest2 = distance;
@@ -560,7 +570,6 @@ extern void GPS_Math_SubPolyline( const QPoint& pt1, const QPoint& pt2, int thre
         if(distance < (threshold<<1))
         {
             idx21 = 0;
-            idx22 = 1;
             pt21 = px;
         }
         else
@@ -570,13 +579,12 @@ extern void GPS_Math_SubPolyline( const QPoint& pt1, const QPoint& pt2, int thre
             if(distance < (threshold<<1))
             {
                 idx21 = line1.size() - 2;
-                idx22 = line1.size() - 1;
                 pt21 = px;
             }
         }
     }
 
-//    qDebug() << line1.size() << idx11 << idx12 << idx21 << idx22 << pt1 << pt2 << pt11 << pt21;
+//    qDebug() << line1.size() << idx11 << idx12 << idx21 << pt1 << pt2 << pt11 << pt21;
 
     // copy segment of line 1 to line2
     if(idx11 != -1 && idx21 != -1)
@@ -613,3 +621,29 @@ extern void GPS_Math_SubPolyline( const QPoint& pt1, const QPoint& pt2, int thre
 
     }
 }
+
+extern bool GPS_Math_LineCrossesRect(const QPoint& p1, const QPoint& p2, const QRect& rect)
+{
+
+    // the trival case
+    if(rect.contains(p1) || rect.contains(p2))
+    {
+        return true;
+    }
+
+    double slope    = double(p2.y() - p1.y()) / (p2.x() - p1.x());
+    double offset   = p1.y() - slope * p1.x();
+    double y1       = offset + slope * rect.left();
+    double y2       = offset + slope * rect.right();
+
+    if((y1 < rect.top()) && (y2 < rect.top()))
+    {
+        return false;
+    }
+    else if((y1 > rect.bottom()) && (y2 > rect.bottom()))
+    {
+        return false;
+    }
+
+    return true;
+}
