@@ -92,10 +92,6 @@ class IMouse : public QObject
 #ifdef GPX_EXTENSIONS
         CGpxExtTr tr_ext;        //TODO: CGpxExtPt -> tr_ext
 #endif
-
-    signals:
-        void sigTrkPt(CTrack::pt_t *  pt);
-
     protected slots:
         void slotSetPos1();
 
