@@ -21,6 +21,7 @@
 
 #include "IItem.h"
 
+#include <QKeyEvent>
 #include <QObject>
 #include <QPixmap>
 #include <QPointer>
@@ -61,6 +62,11 @@ class IOverlay : public IItem
         */
         virtual bool mouseActionInProgress(){return false;}
 
+        /// get key press event when selected
+        virtual void keyPressEvent(QKeyEvent * e){}
+        /// get key release event when selected
+        virtual void keyRelaseEvent(QKeyEvent * e){}
+
         /// get mouse move event when selected
         virtual void mouseMoveEvent(QMouseEvent * e){}
         /// get mouse press event when selected
